@@ -51,8 +51,12 @@
 #' plot(reg_para_ik)
 
 
-rdd_reg_lm <- function(rdd_object, covariates = NULL, order = 1, bw = NULL, slope = c("separate", "same"), covar.opt = list(strategy = c("include", 
-    "residual"), slope = c("same", "separate"), bw = NULL), covar.strat = c("include", "residual"), weights) {
+rdd_reg_lm <- function(rdd_object, covariates = NULL, order = 1, bw = NULL,
+                       slope = c("separate", "same"),
+                       covar.opt = list(strategy = c("include", "residual"),
+                                        slope = c("same", "separate"),
+                                        bw = NULL),
+                       covar.strat = c("include", "residual"), weights) {
     
     checkIsRDD(rdd_object)
     cutpoint <- getCutpoint(rdd_object)
@@ -61,7 +65,7 @@ rdd_reg_lm <- function(rdd_object, covariates = NULL, order = 1, bw = NULL, slop
     slope <- match.arg(slope)
     
     if (!missing(covar.strat)) 
-        warning("covar.strat is (soon) deprecated arg!")
+      stop("covar.strat is deprecated, use covar.opt = list(strategy=...) instead")
     if (!missing(weights) & !is.null(bw)) 
         stop("Cannot give both 'bw' and 'weights'")
     
